// Treequivalence ; UVa 10729

#include <iostream>
#include <cstdio>
#include <string>

#define LG_CODE 1024
#define FILS_MAX 200
int t;

typedef struct s_arbre {
  char lab;
  int nb_fils;
  int pere;
  int rang;
  int fils[FILS_MAX];
} arbre;

char code[LG_CODE];

arbre tree1[FILS_MAX], tree2[FILS_MAX];	

void lit_arbre(char **code, arbre tree[], int *i, int pere);
	
void lit_sous_arbres(char **code, arbre tree[], int *i, int pere) {
  lit_arbre(code, tree, i, pere);
  while (**code == ',' || **code == ' ') {
    (*code)++; // saute ','
    lit_arbre(code, tree, i, pere);
  }
}

void lit_arbre(char **code, arbre tree[], int *i, int pere){
  tree[*i].lab = **code;
  tree[*i].nb_fils = 0;
  tree[*i].pere = pere;
  if (pere >= 0) { // ajoute le fils au pre
    tree[pere].fils[tree[pere].nb_fils] = *i;
    tree[*i].rang = tree[pere].nb_fils;
    tree[pere].nb_fils++;
  }
  (*i)++;
  (*code)++;
  if (**code != '(')
    return;
  (*code)++; // saute '('
  lit_sous_arbres(code, tree, i, (*i)-1);
  (*code)++; //saute ')'
}

int lit_code(char *code, arbre tree[]) {
  int i = 0;
  lit_arbre(&code, tree, &i, -1);
  return i; // nombre de noeuds
}

void encode_depuis_x_vers_y(char **s_out, arbre tree[],
			    int x, int y, int x_est_pere_de_y) {

  sprintf(*s_out, "%c", tree[y].lab);
  (*s_out)++;
	
  if (x_est_pere_de_y) {
		
    if (tree[y].nb_fils > 0) {
      sprintf(*s_out, "(");
      (*s_out)++;
      for(int j = 0; j < tree[y].nb_fils; j++) {
	encode_depuis_x_vers_y(s_out, tree, y, tree[y].fils[j], 1);
	sprintf(*s_out, ",");
	(*s_out)++;
      }
      sprintf(*s_out-1, ")");
    }
	
  } else { // x est un fils de y
	
    if (tree[y].nb_fils > 1 || tree[y].pere >= 0) { // y aura des enfants
      sprintf(*s_out, "(");
      (*s_out)++;
      for(int j = tree[x].rang+1; j < tree[y].nb_fils; j++) {
	encode_depuis_x_vers_y(s_out, tree, y, tree[y].fils[j], 1);
	sprintf(*s_out, ",");
	(*s_out)++;
      }
      if (tree[y].pere >= 0) {
	encode_depuis_x_vers_y(s_out, tree, y, tree[y].pere, 0);
	sprintf(*s_out, ",");
	(*s_out)++;
      }
      for(int j = 0; j < tree[x].rang; j++) {
	encode_depuis_x_vers_y(s_out, tree, y, tree[y].fils[j], 1);
	sprintf(*s_out, ",");
	(*s_out)++;
      }
      sprintf(*s_out-1, ")");
    }
  }
}

char *encode_depuis_feuille(arbre tree[], int feuille) {
  char *s, *t;
	
  s = (char*)calloc(3*FILS_MAX, sizeof(char));

  if (tree[feuille].pere < 0) {
    // arbre rduit  un point
    *s = tree[feuille].lab;
    return s;
  }
	
  sprintf(s, "%c(", tree[feuille].lab);
  t = s+2;
  encode_depuis_x_vers_y(&t, tree, feuille, tree[feuille].pere, 0);
  sprintf(t, ")");
  return s;
}

char *encode_depuis_racine(arbre tree[]) {
  char *s, *t;
	
  s = (char*)calloc(3*FILS_MAX, sizeof(char));
	
  if (tree[0].nb_fils <= 0) {
    // arbre rduit  un point
    *s = tree[0].lab;
    return s;
  }
	
  sprintf(s, "%c(", tree[0].lab);
  t = s+2;
  encode_depuis_x_vers_y(&t, tree, 0, tree[0].fils[0], 1);
  sprintf(t, ")");
  return s;
}

char * encodage_normal(arbre tree[], int nb) {
  char *s, *t, lab_min;

  s = (char*)calloc(3*FILS_MAX, sizeof(char));
	
  sprintf(s,"a"); // majorant de toutes les chanes car a > Z
  lab_min = 'a';
	
  if (nb == 1) {
    // arbre rduit  un point
    *s = tree[0].lab;
    return s;
  }
		
  if (tree[0].nb_fils == 1) {
    lab_min = tree[0].lab;
  }
	
  for(int i = 1; i < nb; i++) { // recherche le label min d'une feuille
    if ((tree[i].nb_fils == 0) && (tree[i].lab < lab_min)) { // cette feuille
      lab_min = tree[i].lab;
    }
  }

  for(int i = 0; i < nb; i++) {
    // essaie depuis cette feuille
    if ((tree[i].nb_fils == 0) && (tree[i].lab == lab_min)) {
      t = encode_depuis_feuille(tree, i);
      if (strcmp(t,s) < 0) {
	strcpy(s,t);
      }
    }
    if ((tree[i].pere <= 0) && (tree[i].nb_fils == 1) &&
	(tree[i].lab == lab_min)) {
      t = encode_depuis_racine(tree);
      if (strcmp(t,s) < 0) {
	strcpy(s,t);
      }
    }
  }	
  return s;
}

int main () {

  std::cin >> t;
  for(; t > 0; t--) {
    int nb1, nb2;
    char *s1,*s2;
    std::cin >> code;
    nb1 = lit_code(code,tree1);
    s1 = encodage_normal(tree1, nb1);

    std::cin >> code;
    nb2 = lit_code(code,tree2);
    s2 = encodage_normal(tree2, nb2);

    if (nb1 != nb2 || strcmp(s1,s2)) {
      std::cout << "different\n";
    } else {
      std::cout << "same\n";
    }
  }	
	
  return 0;
}
